# Table of Contents

- [software-bill-of-materials-sbom](<./software-bill-of-materials-sbom.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Software Bill of Materials (SBOM)](<./Software-Bill-of-Materials-SBOM.md>)
  - [Overview](<./Software-Bill-of-Materials-SBOM/Overview.md>)
  - [Step 1: Generate SBOMs](<./Software-Bill-of-Materials-SBOM/Step-1-Generate-SBOMs.md>)
  - [Step 2: Upload SBOMs Through the API](<./Software-Bill-of-Materials-SBOM/Step-2-Upload-SBOMs-Through-the-API.md>)
  - [Step 3: View SBOMs in the SBOM Explorer](<./Software-Bill-of-Materials-SBOM/Step-3-View-SBOMs-in-the-SBOM-Explorer.md>)
  - [Permissions](<./Software-Bill-of-Materials-SBOM/Permissions.md>)
  - [Additional Resources](<./Software-Bill-of-Materials-SBOM/Additional-Resources.md>)
  - [Was this page helpful?](<./Software-Bill-of-Materials-SBOM/Was-this-page-helpful.md>)
